@@ -323,7 +323,7 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 		digits += (len - dlen);
 	}
 
-	while(*match)
+	while(*match && *digits)
 	{
 		inc = true;
 		switch(*match)
@@ -360,8 +360,11 @@ bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 			++digits;
 		++match;	
 	}
-	if(*digits)
-		return partial;
+        if(*match && !*digits)
+                return partial;
+
+        if(*match && *digits)
+                return false;
 
 	return true;
 }
