@@ -976,6 +976,16 @@ public:
          */
 	virtual unsigned saycount(BayonneSession *session, unsigned count, const char *string);
 
+        /**
+         * Translate a string for time into short hours.
+         *
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
+         * @param string to be processed.
+         * @return new count of prompts used.
+         */
+        virtual unsigned sayhour(BayonneSession *session, unsigned count, const char *string);
+
         /**
          * Translate a string for time into speech.
          *
@@ -996,6 +1006,16 @@ public:
          */
 	virtual unsigned weekday(BayonneSession *session, unsigned count, const char *string);
 
+	/*
+	 * Translate a string with a date into spoken date without year.
+         *
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
+         * @param string to be processed.
+         * @return new count of prompts used.
+         */
+        virtual unsigned sayday(BayonneSession *session, unsigned count, const char *string);
+
         /**
          * Translate a string with a date into a spoken date.
          *
