@@ -418,11 +418,12 @@ const char *Driver::assignScript(ScriptImage *img, Line *line)
 	const char *cp;
 	char *ep, *contact;
 	Registry *reg;
+	const char *host, *port;
 
 	for(;;)
 	{
 		cp = line->args[idx++];
-		if(!cp)
+		if(!cp && idx > 1)
 			break;
 
 		Registry *reg = (Registry *)img->getMemory(sizeof(Registry));
@@ -451,18 +452,57 @@ const char *Driver::assignScript(ScriptImage *img, Line *line)
 		else
 			ep = "";
 
-		snprintf(uname, sizeof(uname), "%s%s", cbuf, ep);
+                host = strchr(cp, '@');
+                if(host)
+                {
+                        ++host;
+                        ep = strrchr((char *)host, ':');
+                        if(ep)
+                                *ep = 0;
+                        reg->address = host;
+                        setString(uname, sizeof(uname), cp);
+                        ep = strchr(uname, '@');
+                        if(ep)
+                                *ep = 0;
+                }
+                else if(cp)
+		{
+			reg->address = NULL;
+			setString(uname, sizeof(uname), cp);
+		}
+		else
+                {
+                        reg->address = NULL;
+                        snprintf(uname, sizeof(uname), "%s%s", cbuf, ep);
+                }
+
 		snprintf(rname, sizeof(rname), "uri.%s", uname);
-		snprintf(buffer, sizeof(buffer), "sip:%s@%s",
-			uname, getLast("interface"));
+                host = getLast("interface");
+                if(reg->address)
+                {
+                        port = strrchr(host, ':');
+                        host = reg->address;
+                }
+                else
+                        port = "";
+
+                snprintf(buffer, sizeof(buffer), "sip:%s@%s%s",
+                        uname, host, port);
+
 		ep = strrchr(buffer, ':');
 		if(ep && !stricmp(ep, ":5060"))
 			*ep = 0;	
 		contact = (char *)img->getMemory(strlen(buffer) + 1);
 		strcpy(contact, buffer);
 		reg->contact = (const char *)contact;
+		if(!reg->uri)
+			reg->uri = reg->contact;
+                reg->localid = (char *)img->getMemory(strlen(uname) + 1);
+                strcpy((char *)reg->localid, uname);
 		slog.debug("sip: assigning %s to %s", scr->name, buffer);
 		img->setPointer(rname, reg);
+		if(!cp)
+			break;
 	}
 	return "";
 }
@@ -481,13 +521,14 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	long mult = 60000;
 	osip_message_t *msg = NULL; 
 
-	if(!ScriptChecks::useKeywords(line, "=uri=timeout=server=proxy=userid=secret=type=realm=dtmf"))
+	if(!ScriptChecks::useKeywords(line, "=uri=timeout=server=proxy=userid=secret=type=realm=dtmf=public"))
 		return "invalid keywords for sip, use uri, timeout, proxy, userid, secret, port";
 
 	reg->active = false;
 	reg->protocol = "sip";
 	reg->iface = getLast("interface");
 	reg->uri = ScriptChecks::findKeyword(line, "uri");
+	reg->address = ScriptChecks::findKeyword(line, "public");
 	reg->hostid = ScriptChecks::findKeyword(line, "proxy");
 	reg->userid = ScriptChecks::findKeyword(line, "userid");
 	reg->secret = ScriptChecks::findKeyword(line, "secret");
@@ -590,7 +631,17 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	buf[len] = 0;
 	pos = len;
 
-	setString(buf + pos, sizeof(buf) - pos, reg->iface);
+        if(reg->address)
+        {
+                cp = strrchr(reg->iface, ':');
+                if(!cp)
+                        cp = "";
+                snprintf(buf + pos, sizeof(buf) - pos, "%s%s",
+                        reg->address, cp);
+        }
+        else
+		setString(buf + pos, sizeof(buf) - pos, reg->iface);
+
 	len = strlen(buf) + 1;
 	reg->contact = (const char *)img->getMemory(len);
 	strcpy((char *)reg->contact, buf);
@@ -693,7 +744,7 @@ void Driver::run(void)
         Event event;
 	char buf[1024];
 	char cbuf[256];
-	Registry *reg, *peer;
+	Registry *reg, *peer, *proxy;
 	Name *scr;
 	ScriptImage *img;
 	const char *cp, *lcp;
@@ -943,7 +994,7 @@ exitcall:
 			}
 			eXosip_unlock();
 			data_rtpmap = session->getSymbol("session.rtpmap");
-			cp = getLast("localip");
+                        cp = session->getSymbol("session.ip_public");
 			if(local_sdp && remote_sdp && session->dtmf_payload)
                         	snprintf(buf, sizeof(buf),
                                 	"v=0\r\n"
@@ -1145,6 +1196,16 @@ killit:
 				display = caller;
 
 			img = useImage();
+
+                        if(to->url->port && stricmp(to->url->port, "5060"))                                     snprintf(buf, sizeof(buf), "sip.%s:%s",
+                                        to->url->host, to->url->port);
+                        else
+                                snprintf(buf, sizeof(buf), "sip.%s",
+                                        to->url->host); 
+                        proxy = (Registry *)img->getPointer(buf);
+                        if(proxy && !proxy->isActive())
+                                goto sip404;
+
 			if(from->url->port && stricmp(from->url->port, "5060"))
 				snprintf(buf, sizeof(buf), "sip.%s:%s",
 					from->url->host, from->url->port);
@@ -1166,20 +1227,28 @@ killit:
 				auth = reg->type;
 			if(!strnicmp(auth, "ext", 3))
 				auth = "peer";
-			if(!stricmp(auth, "friend"))
+			if(!stricmp(auth, "friend") && peer)
 				auth = "peer";
+			else if(!stricmp(auth, "friend") && proxy)
+				auth = "proxy";
+			else if(!stricmp(auth, "friend"))
+				reg = NULL;
+			if(proxy && !reg && !stricmp(auth, "proxy"))
+				reg = proxy;
 			if(peer && !reg && !stricmp(auth, "peer"))
 				reg = peer;
 			if(reg && !peer && !stricmp(auth, "peer"))
 				reg = NULL;
 			if(reg && !peer && !stricmp(auth, "user"))
 				reg = NULL;
+                        if(reg && !proxy && !stricmp(auth, "proxy"))
+                                reg = NULL; 
 			if(reg)
 			{
 				if(!reg->isActive())
 					goto sip404;
 
-				scr = reg->scr;
+				scr = img->getScript(reg->scr->name);
 				cp = reg->dtmf;
 				if(cp && *cp)
 				{
@@ -1217,6 +1286,19 @@ sip404:
 			}
 		
 			session = (Session *)(s);
+                        cp = getLast("localip");
+                        if(reg->address)
+                        {
+                                InetAddress host(reg->address);
+                                snprintf(cbuf, sizeof(cbuf), "%s",
+                                        inet_ntoa(host.getAddress()));
+                                session->setConst("session.ip_public", cbuf);
+                        }
+                        else
+                                session->setConst("session.ip_public", cp);
+
+                        session->setConst("session.ip_local", cp);
+
 			session->cid = sevent->cid;
 			session->did = sevent->did;
 			session->setConst("session.info", auth);
@@ -1297,7 +1379,7 @@ sip415:
                                 inet_ntoa(session->remote_address.getAddress()),                                session->getRemotePort());
                         session->setConst("session.rtp_remote", buf);  
 
-			cp = getLast("localip");
+                        cp = session->getSymbol("session.ip_public");
 			sdp = newString("", 4096);
 			snprintf(sdp, 4096, 
 				"v=0\r\n"
