@@ -155,9 +155,11 @@ bool Session::enterSeize(Event *event)
 	Registry *reg = NULL;
 	ScriptImage *img = getImage();
 	char rbuf[16];
+	char cbuf[65];
 	char sdp[512];
 	const char *rtpmap;
 	const char *route;
+        const char *lp = driver->getLast("localip");
 
 	switch(event->id)
 	{
@@ -212,12 +214,23 @@ dialing:
 			snprintf(rbuf, sizeof(rbuf), "sipreg.%d", reg->regid);
 			setConst("session.registry", rbuf);
 			setConst("session.uri_local", reg->contact);
+                        if(reg->address)
+                        {
+                                InetAddress host(reg->address);
+                                snprintf(cbuf, sizeof(cbuf), "%s",
+                                        inet_ntoa(host.getAddress()));
+                                setConst("session.ip_public", cbuf);
+                        }
+                        else
+                                setConst("session.ip_public", lp);
 		}
 		else
 		{
 			snprintf(buf, sizeof(buf), "sip:anon@%s",
 				Driver::sip.getLast("interface"));
 			setConst("session.uri_local", buf);
+                        setConst("session.ip_local", lp);
+                        setConst("session.ip_public", lp);
 		}
 			
 		to = getSymbol("session.uri_remote");
