@@ -166,6 +166,12 @@ namespace Bayonne
 			return true;
 		}
 
+		public void postSymbol(string id, string value)
+		{
+			string sid = getHead("SESSION");
+			_out.WriteLine(sid + " POST " + id + " " + value);			
+		}
+
 		public string getPath(string file)
 		{
 			string ext = getHead("EXTENSION");
