@@ -720,6 +720,64 @@ bool Methods::scrErase(void)
 	return true;
 }	
 
+#ifndef	WIN32
+
+bool Methods::scrLink(void)
+{
+	const char *cp = getAudio(false);
+	const char *dp;
+	const char *se, *de;
+	char buf1[MAX_PATHNAME], buf2[MAX_PATHNAME];
+	
+	if(cp)
+	{
+		slog.error("%s: %s", logname, cp);
+		error("invalid-link");
+		return true;
+	}
+
+	cp = getWritepath(buf1, sizeof(buf1));
+	if(!cp)
+	{
+		error("invalid-source");
+		return true;
+	}
+
+	dp = getWritepath(buf2, sizeof(buf2));	
+	if(!cp)
+	{
+		error("invalid-target");
+		return true;
+	}
+
+	se = strrchr(cp, '.');
+	de = strrchr(dp, '.');
+
+	if(!se || !de)
+	{
+		error("invalid-names");
+		return true;
+	}
+
+	if(stricmp(se, de))
+	{
+		error("filename-mismatch");
+		return true;
+	}
+
+	if(link(cp, dp))
+	{
+		if(!signalScript(SIGNAL_FAIL))
+			error("link-failed");
+		return true;
+	}
+
+	advance();
+	return true;
+}	
+
+#endif
+
 bool Methods::scrMove(void)
 {
 	const char *cp = getAudio(false);
