@@ -93,6 +93,13 @@ ScriptRuntime()
 			(Check)&Checks::chkSleep},
 		{"route", false, (Method)&Methods::scrRoute,
 			(Check)&Checks::chkRoute},
+#ifdef  WIN32
+                {"link", false, (Method)&Methods::scrCopy,
+                        (Check)&Checks::chkMove},
+#else
+                {"link", false, (Method)&Methods::scrLink,
+                        (Check)&Checks::chkMove},
+#endif
 		{"copy", false, (Method)&Methods::scrCopy,
 			(Check)&Checks::chkMove},
 		{"move", false, (Method)&Methods::scrMove,
@@ -636,6 +643,7 @@ bool Runtime::command(char *cmd)
 	bool rtn;
 	BayonneDriver *d;
 	const char *dial, *caller, *display;
+	char buf[65];
 
 	cmd = strtok_r(cmd, " \t\r\n", &tok);
 	if(!cmd || ispunct(*cmd) || !*cmd)
@@ -669,6 +677,17 @@ bool Runtime::command(char *cmd)
 		return true;
 	}
 		
+        if(!stricmp(cmd, "define"))
+        {
+                cmd = strtok_r(NULL, " \t\r\n", &tok);
+                if(!cmd)
+                        return false;
+
+                snprintf(buf, sizeof(buf), "%s.def", cmd);
+                Bayonne::server->setValue("definitions", buf);
+                return true;
+        }
+
 	if(!stricmp(cmd, "load"))
 	{
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
